pub struct AdminPage {
pub shell: Shell,
pub tables: Vec<FunnelTable>,
pub queue_depth: i64,
pub jobs: Vec<JobRow>,
}Fields
shell: Shelltables: Vec<FunnelTable>queue_depth: i64jobs: Vec<JobRow>Trait Implementations
Sourceimpl Display for AdminPage
impl Display for AdminPage
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for AdminPage
impl FastWritable for AdminPage
Sourceimpl Template for AdminPage
impl Template for AdminPage
Sourceconst SIZE_HINT: usize = 14312usize
const SIZE_HINT: usize = 14312usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for AdminPage
impl RefUnwindSafe for AdminPage
impl Send for AdminPage
impl Sync for AdminPage
impl Unpin for AdminPage
impl UnsafeUnpin for AdminPage
impl UnwindSafe for AdminPage