pub struct AuditLive {
pub base: String,
pub banner: bool,
pub active: bool,
pub state: &'static str,
pub line: String,
pub sub: String,
}Expand description
The live crawl line: the first-crawl progress block, or the slim banner over a finished audit. Polls itself every 2 s while a crawl is queued or running.
Fields
base: Stringactive: boolA crawl is queued or running.
state: &'static strqueued or running, for the status dot.
line: Stringsub: StringTrait Implementations
Sourceimpl Display for AuditLive
impl Display for AuditLive
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for AuditLive
impl FastWritable for AuditLive
Sourceimpl Template for AuditLive
impl Template for AuditLive
Sourceconst SIZE_HINT: usize = 562usize
const SIZE_HINT: usize = 562usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for AuditLive
impl RefUnwindSafe for AuditLive
impl Send for AuditLive
impl Sync for AuditLive
impl Unpin for AuditLive
impl UnsafeUnpin for AuditLive
impl UnwindSafe for AuditLive