pub struct BillingPage {
pub shell: Shell,
pub configured: bool,
pub plan_name: &'static str,
pub paid: bool,
pub period_end: Option<String>,
pub cancelled: bool,
pub has_customer: bool,
pub cards: Vec<PlanCard>,
pub success: bool,
pub error: Option<String>,
pub stopped_sites: bool,
}Fields
shell: Shellconfigured: boolplan_name: &'static strpaid: boolperiod_end: Option<String>When the paid period ends (the next billing date), for a paid plan.
cancelled: boolThe subscription was cancelled: the plan ends on period_end instead of renewing.
has_customer: boolcards: Vec<PlanCard>success: boolerror: Option<String>stopped_sites: boolTrait Implementations
Sourceimpl Display for BillingPage
Implement the format!() trait for BillingPage
impl Display for BillingPage
Implement the format!() trait for BillingPage
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for BillingPage
impl FastWritable for BillingPage
Sourceimpl Template for BillingPage
impl Template for BillingPage
Sourceconst SIZE_HINT: usize = 14288usize
const SIZE_HINT: usize = 14288usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for BillingPage
impl RefUnwindSafe for BillingPage
impl Send for BillingPage
impl Sync for BillingPage
impl Unpin for BillingPage
impl UnsafeUnpin for BillingPage
impl UnwindSafe for BillingPage