pub struct ChangeView {
pub severity: &'static str,
pub severity_label: &'static str,
pub title: String,
pub path: Option<String>,
pub href: Option<String>,
pub mode: &'static str,
pub mode_icon: &'static str,
pub before: String,
pub after: String,
pub after_class: &'static str,
}Fields
severity: &'static strcritical, warning, notice
severity_label: &'static strtitle: Stringpath: Option<String>The URL’s path and query; None for site-wide changes.
href: Option<String>Explorer selection link, when the URL is a page on the site that the latest crawl has.
mode: &'static strmode_icon: &'static strbefore: Stringafter: Stringafter_class: &'static str critical, warning or empty, appended to the .after class.