pub struct ChangesPage {
pub shell: Shell,
pub base: String,
pub empty: Option<EmptyState>,
pub cmp: Option<Comparison>,
}Fields
shell: Shellbase: Stringempty: Option<EmptyState>Set when there is nothing to compare yet.
cmp: Option<Comparison>Trait Implementations
Sourceimpl Display for ChangesPage
Implement the format!() trait for ChangesPage
impl Display for ChangesPage
Implement the format!() trait for ChangesPage
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for ChangesPage
impl FastWritable for ChangesPage
Sourceimpl Template for ChangesPage
impl Template for ChangesPage
Sourceconst SIZE_HINT: usize = 12426usize
const SIZE_HINT: usize = 12426usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for ChangesPage
impl RefUnwindSafe for ChangesPage
impl Send for ChangesPage
impl Sync for ChangesPage
impl Unpin for ChangesPage
impl UnsafeUnpin for ChangesPage
impl UnwindSafe for ChangesPage