pub struct CrawlerPartial {
pub crawler: CrawlerView,
}Fields
crawler: CrawlerViewTrait Implementations
Sourceimpl Display for CrawlerPartial
Implement the format!() trait for CrawlerPartial
impl Display for CrawlerPartial
Implement the format!() trait for CrawlerPartial
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for CrawlerPartial
impl FastWritable for CrawlerPartial
Sourceimpl Template for CrawlerPartial
impl Template for CrawlerPartial
Sourceconst SIZE_HINT: usize = 403usize
const SIZE_HINT: usize = 403usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for CrawlerPartial
impl RefUnwindSafe for CrawlerPartial
impl Send for CrawlerPartial
impl Sync for CrawlerPartial
impl Unpin for CrawlerPartial
impl UnsafeUnpin for CrawlerPartial
impl UnwindSafe for CrawlerPartial