pub struct StarButton {
pub base: String,
pub hex: String,
pub on: bool,
pub pop: bool,
pub at: &'static str,
}Expand description
The key-page star, in a grid row (at = "row") or the detail tab bar ("detail").
Fields
base: Stringhex: Stringon: boolpop: boolPlay the pop animation (just starred).
at: &'static strTrait Implementations
Sourceimpl Display for StarButton
Implement the format!() trait for StarButton
impl Display for StarButton
Implement the format!() trait for StarButton
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for StarButton
impl FastWritable for StarButton
Sourceimpl Template for StarButton
impl Template for StarButton
Sourceconst SIZE_HINT: usize = 363usize
const SIZE_HINT: usize = 363usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for StarButton
impl RefUnwindSafe for StarButton
impl Send for StarButton
impl Sync for StarButton
impl Unpin for StarButton
impl UnsafeUnpin for StarButton
impl UnwindSafe for StarButton