pub struct StartDone {
pub domain: String,
pub email: String,
pub site: SiteNote,
pub audit_href: Option<String>,
pub key: Option<MintedKey>,
pub key_limit: i64,
pub mcp_url: String,
}Expand description
What confirming did.
Fields
domain: Stringemail: Stringsite: SiteNoteaudit_href: Option<String>The site’s audit screen, when the account has the site.
key: Option<MintedKey>The key just minted; None when the account is at its key limit.
key_limit: i64mcp_url: StringAuto Trait Implementations
impl Freeze for StartDone
impl RefUnwindSafe for StartDone
impl Send for StartDone
impl Sync for StartDone
impl Unpin for StartDone
impl UnsafeUnpin for StartDone
impl UnwindSafe for StartDone