pub struct MainPartial {
pub main: MainView,
pub unlock: UnlockCard,
}Fields
main: MainViewunlock: UnlockCardTrait Implementations
Sourceimpl Display for MainPartial
Implement the format!() trait for MainPartial
impl Display for MainPartial
Implement the format!() trait for MainPartial
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for MainPartial
impl FastWritable for MainPartial
Sourceimpl Template for MainPartial
impl Template for MainPartial
Sourceconst SIZE_HINT: usize = 541usize
const SIZE_HINT: usize = 541usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for MainPartial
impl RefUnwindSafe for MainPartial
impl Send for MainPartial
impl Sync for MainPartial
impl Unpin for MainPartial
impl UnsafeUnpin for MainPartial
impl UnwindSafe for MainPartial