pub struct KeysPage {
pub shell: Shell,
pub keys: Vec<KeyView>,
pub form: CreateForm,
pub new_key: Option<ShownKey>,
pub usage: String,
pub mcp_url: String,
pub max_keys: i64,
}Fields
shell: Shellkeys: Vec<KeyView>form: CreateFormnew_key: Option<ShownKey>usage: String37 of 100 API calls used today, or the unlimited wording.
mcp_url: StringThe /mcp address.
max_keys: i64Trait Implementations
Sourceimpl Display for KeysPage
impl Display for KeysPage
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for KeysPage
impl FastWritable for KeysPage
Sourceimpl Template for KeysPage
impl Template for KeysPage
Sourceconst SIZE_HINT: usize = 14825usize
const SIZE_HINT: usize = 14825usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for KeysPage
impl RefUnwindSafe for KeysPage
impl Send for KeysPage
impl Sync for KeysPage
impl Unpin for KeysPage
impl UnsafeUnpin for KeysPage
impl UnwindSafe for KeysPage